;gnus;; guix-environment.el --- Enter and manage guix profile environments  -*- lexical-binding: t; -*-

;; Copyright (C) 2016  

;; Author:  <sbaugh@catern.com>
;; Keywords: unix, processes, tools

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;; 

;;; Code:

(require 'cl-lib)
(require 'environment)
(require 'guix-profiles)
(require 'guix-geiser)
(require 'guix-backend)

(defun guix-environment-get (profile)
  "Get the variable bindings for this profile"
  (guix-eval-read "(use-modules (guix search-paths))")
  (guix-eval-read (format "(let* ((profile \"%s\" )
       (search-paths (delete-duplicates
		      (cons $PATH (append-map manifest-entry-search-paths
					      (manifest-entries (profile-manifest profile)))))))
  (filter-map (lambda (x) (cons (search-path-specification-variable (car x)) (cdr x)))
	      (evaluate-search-paths search-paths (list profile) getenv)))" profile)))

(defvar guix-environment-augment-path nil
  "When setting an environment, augment the path instead of replacing it")

(defun guix-environment-set-dir (profile dir)
  "Get the variable bindings for this profile"
  (interactive
   (let ((profile (guix-profile-prompt)))
     (list profile (read-file-name (concat "Directory to associate with profile " profile " : ")
				   nil nil 'confirm))))
  (let ((env (guix-environment-get profile)))
    (when guix-environment-augment-path
      (setq env (cons (cons "PATH" (concat (getenv "PATH") ":" (cdr (assoc "PATH" env)))) env)))
    (setq env (environment-create (cl-remove-duplicates (append env (environment-current-as-alist)) :key #'car)))
    (environment-associate-dir dir env)))

(provide 'guix-environment)
;;; guix-environment.el ends here
